/**
 * easyWSDL - easyWSDL toolbox Platform.
 * Copyright (c) 2008,  eBM Websourcing
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.ow2.easywsdl.wsdl.decorator;

import java.util.List;
import java.util.Map;

import javax.xml.namespace.QName;

import org.ow2.easywsdl.schema.api.Documentation;
import org.ow2.easywsdl.schema.api.XmlException;
import org.ow2.easywsdl.schema.api.abstractElmt.AbstractSchemaElementImpl;
import org.ow2.easywsdl.wsdl.api.WSDLElement;
import org.ow2.easywsdl.wsdl.api.WSDLException;
import org.ow2.easywsdl.wsdl.api.abstractElmt.AbstractWSDLElementImpl;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfBindingFault;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfBindingInput;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfBindingOperation;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfBindingOutput;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfOperation;
import org.ow2.easywsdl.wsdl.api.abstractItf.AbsItfBinding.StyleConstant;
import org.ow2.easywsdl.wsdl.api.binding.BindingProtocol.SOAPMEPConstants;
import org.w3c.dom.Element;


/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@SuppressWarnings("unchecked")
public class DecoratorBindingOperationImpl<O extends AbsItfOperation, BIn extends AbsItfBindingInput, BOut extends AbsItfBindingOutput, BF extends AbsItfBindingFault>  extends AbstractWSDLElementImpl implements Decorator {

    /**
	 *
	 */
    private static final long serialVersionUID = 1L;

    protected AbsItfBindingOperation<O, BIn, BOut, BF> bindingOperation;

    public DecoratorBindingOperationImpl(final AbsItfBindingOperation<O, BIn, BOut, BF> bindingOperation)
            throws WSDLException {
        this.bindingOperation = bindingOperation;
    }

    public void addFault(final BF arg0) {
        this.bindingOperation.addFault(arg0);
    }

    public BF getFault(final String arg0) {
        return this.bindingOperation.getFault(arg0);
    }

    public List<BF> getFaults() {
        return this.bindingOperation.getFaults();
    }

    public String getHttpContentEncodingDefault() {
        return this.bindingOperation.getHttpContentEncodingDefault();
    }

    public String getHttpFaultSerialization() {
        return this.bindingOperation.getHttpFaultSerialization();
    }

    public String getHttpInputSerialization() {
        return this.bindingOperation.getHttpInputSerialization();
    }

    public String getHttpLocation() {
        return this.bindingOperation.getHttpLocation();
    }

    public String getHttpMethod() {
        return this.bindingOperation.getHttpMethod();
    }

    public String getHttpOutputSerialization() {
        return this.bindingOperation.getHttpOutputSerialization();
    }

    public String getHttpQueryParameterSeparator() {
        return this.bindingOperation.getHttpQueryParameterSeparator();
    }

    public BIn getInput() {
        return this.bindingOperation.getInput();
    }

    public SOAPMEPConstants getMEP() {
        return this.bindingOperation.getMEP();
    }

    public O getOperation() {
        return this.bindingOperation.getOperation();
    }

    public BOut getOutput() {
        return this.bindingOperation.getOutput();
    }

    public QName getQName() {
        return this.bindingOperation.getQName();
    }

    public String getSoapAction() {
        return this.bindingOperation.getSoapAction();
    }

    public StyleConstant getStyle() {
        return this.bindingOperation.getStyle();
    }

    public boolean isHttpIgnoreUncited() {
        return this.bindingOperation.isHttpIgnoreUncited();
    }

    public BF removeFault(final String arg0) {
        return this.bindingOperation.removeFault(arg0);
    }

    public void setInput(final BIn arg0) {
        this.bindingOperation.setInput(arg0);
    }

    public void setMEP(final SOAPMEPConstants arg0) {
        this.bindingOperation.setMEP(arg0);
    }

    public void setOutput(final BOut arg0) {
        this.bindingOperation.setOutput(arg0);
    }

    public void setQName(final QName arg0) {
        this.bindingOperation.setQName(arg0);
    }

    public Documentation createDocumentation() {
        return this.bindingOperation.createDocumentation();
    }

    public Documentation getDocumentation() {
        return this.bindingOperation.getDocumentation();
    }

    public Map<QName, String> getOtherAttributes() throws XmlException {
        return this.bindingOperation.getOtherAttributes();
    }

    public List<Element> getOtherElements() throws XmlException {
        return this.bindingOperation.getOtherElements();
    }

    public void setDocumentation(final Documentation arg0) {
        this.bindingOperation.setDocumentation(arg0);
    }

	public BF createFault() {
		return this.bindingOperation.createFault();
	}

	public BIn createInput() {
		return this.bindingOperation.createInput();
	}

	public BOut createOutput() {
		return this.bindingOperation.createOutput();
	}

	public void setSoapAction(String action) {
		this.bindingOperation.setSoapAction(action);
	}

    @Override
	public Object getModel() {
		return ((AbstractWSDLElementImpl)this.bindingOperation).getModel();
	}

    @Override
	public AbstractSchemaElementImpl getParent() {
		return ((AbstractWSDLElementImpl)this.bindingOperation).getParent();
	}

	public WSDLElement getDecorator() {
		return this.bindingOperation;
	}

}
